@@ -40,7 +40,7 @@ class JWTExtension(Extension):
             token_payload = self.get_token_payload(tokenName="JWT_REFRESH_TOKEN")
             if token_payload and token_payload is not None:
                 try:
-                    from models import RefreshTokens
+                    from .models import RefreshTokens
                     refreshTokenObj = RefreshTokens.objects.get(refreshToken=self.request.COOKIES['JWT_REFRESH_TOKEN'])
                     if refreshTokenObj:
                         self.userID = refreshTokenObj.user.id
